@@ -119,6 +119,13 @@ GNode *             egg_asn1x_get_any_as_full        (GNode *node,
                                                       const gchar *type,
                                                       gint options);
 
+GNode *             egg_asn1x_get_any_as_string      (GNode *node,
+                                                      EggAsn1xType type);
+
+GNode *             egg_asn1x_get_any_as_string_full (GNode *node,
+                                                      EggAsn1xType type,
+                                                      gint options);
+
 GBytes *            egg_asn1x_get_any_raw            (GNode *node,
                                                       EggAllocator allocator);
 
@@ -201,6 +208,9 @@ GBytes *            egg_asn1x_get_string_as_bytes    (GNode *node);
 void                egg_asn1x_set_string_as_bytes    (GNode *node,
                                                       GBytes *bytes);
 
+void                egg_asn1x_take_string_as_bytes   (GNode *node,
+                                                      GBytes *bytes);
+
 GBytes *            egg_asn1x_get_string_as_usg      (GNode *node,
 	                                              EggAllocator allocator);
 
@@ -232,16 +242,7 @@ gboolean            egg_asn1x_set_string_as_utf8     (GNode *node,
 
 gchar *             egg_asn1x_get_bmpstring_as_utf8  (GNode *node);
 
-glong               egg_asn1x_get_time_as_long       (GNode *node);
-
-gboolean            egg_asn1x_set_time_as_long       (GNode *node,
-                                                      glong time);
-
-gboolean            egg_asn1x_get_time_as_date       (GNode *node,
-                                                      GDate *date);
-
-gboolean            egg_asn1x_set_time_as_date       (GNode *node,
-                                                      GDate *date);
+GDateTime *         egg_asn1x_get_time_as_date_time  (GNode *node);
 
 GQuark              egg_asn1x_get_oid_as_quark       (GNode *node);
 
@@ -255,12 +256,6 @@ gboolean            egg_asn1x_set_oid_as_string      (GNode *node,
 
 void                egg_asn1x_destroy                (gpointer asn);
 
-glong               egg_asn1x_parse_time_general     (const gchar *time,
-                                                      gssize n_time);
-
-glong               egg_asn1x_parse_time_utc         (const gchar *time,
-                                                      gssize n_time);
-
 gssize              egg_asn1x_element_length         (const guchar *data,
                                                       gsize n_data);
 
