@@ -120,6 +120,8 @@ keytype_to_algo (const gchar *algo,
 		return CKK_RSA;
 	else if (match_word (algo, length, "ssh-dss"))
 		return CKK_DSA;
+	else if (match_word (algo, length, "ssh-ed25519"))
+		return CKK_EC_EDWARDS;
 	else if (length >= 6 && strncmp (algo, "ecdsa-", 6) == 0)
 		return CKK_ECDSA;
 	return G_MAXULONG;
@@ -230,7 +232,7 @@ parse_v1_public_line (const gchar *line,
 	if (word_options)
 		options = g_strndup (word_options, len_options);
 
-	attrs = gck_attributes_ref_sink (gck_builder_end (&builder));
+	attrs = gck_builder_end (&builder);
 
 	if (callback != NULL) {
 		bytes = g_bytes_new_with_free_func (outer, n_outer,
@@ -389,6 +391,20 @@ read_v2_public_ecdsa (EggBuffer *buffer,
 	return TRUE;
 }
 
+static gboolean
+read_v2_public_ed25519 (EggBuffer *buffer,
+                        gsize *offset,
+                        GckBuilder *builder)
+{
+	if (!read_buffer_mpi (buffer, offset, builder, CKA_VALUE))
+		return FALSE;
+
+	gck_builder_add_ulong (builder, CKA_KEY_TYPE, CKK_EC_EDWARDS);
+	gck_builder_add_ulong (builder, CKA_CLASS, CKO_PUBLIC_KEY);
+
+	return TRUE;
+}
+
 static gboolean
 read_v2_public_key (gulong algo,
                     gconstpointer data,
@@ -425,6 +441,9 @@ read_v2_public_key (gulong algo,
 	case CKK_DSA:
 		ret = read_v2_public_dsa (&buffer, &offset, builder);
 		break;
+	case CKK_EC_EDWARDS:
+		ret = read_v2_public_ed25519 (&buffer, &offset, builder);
+		break;
 	case CKK_ECDSA:
 		ret = read_v2_public_ecdsa (&buffer, &offset, builder);
 		break;
@@ -542,7 +561,7 @@ parse_v2_public_line (const gchar *line,
 		gck_builder_add_string (&builder, CKA_LABEL, label);
 	}
 
-	attrs = gck_attributes_ref_sink (gck_builder_end (&builder));
+	attrs = gck_builder_end (&builder);
 
 	if (callback != NULL) {
 		bytes = g_bytes_new_with_free_func (outer, n_outer,
