@@ -106,7 +106,7 @@ struct _GcrSystemPromptPrivate {
 	gchar *last_response;
 };
 
-static void     gcr_system_prompt_prompt_iface         (GcrPromptIface *iface);
+static void     gcr_system_prompt_prompt_iface         (GcrPromptInterface *iface);
 
 static void     gcr_system_prompt_initable_iface       (GInitableIface *iface);
 
@@ -1322,7 +1322,7 @@ gcr_system_prompt_real_close (GcrPrompt *prompt)
 }
 
 static void
-gcr_system_prompt_prompt_iface (GcrPromptIface *iface)
+gcr_system_prompt_prompt_iface (GcrPromptInterface *iface)
 {
 	iface->prompt_password_async = gcr_system_prompt_password_async;
 	iface->prompt_password_finish = gcr_system_prompt_password_finish;
@@ -1362,7 +1362,7 @@ gcr_system_prompt_open_async (gint timeout_seconds,
 }
 
 /**
- * gcr_system_prompt_open_for_prompter_async:
+ * gcr_system_prompt_open_for_prompter_async: (finish-func open_finish):
  * @prompter_name: (nullable): the prompter D-Bus name
  * @timeout_seconds: the number of seconds to wait to access the prompt, or -1
  * @cancellable: (nullable): optional cancellation object
